#[repr(C)]pub struct Color {
pub a: u8,
pub r: u8,
pub g: u8,
pub b: u8,
}Expand description
An 8-bit-per-channel ARGB color.
Fields
a: u8r: u8g: u8b: u8Implementations
Sourceimpl Color
impl Color
Sourcepub const fn argb(a: u8, r: u8, g: u8, b: u8) -> Self
pub const fn argb(a: u8, r: u8, g: u8, b: u8) -> Self
Creates a color from alpha, red, green, and blue channels.
Sourcepub const fn rgb(r: u8, g: u8, b: u8) -> Self
pub const fn rgb(r: u8, g: u8, b: u8) -> Self
Creates an opaque color from red, green, and blue channels.
Sourcepub const fn transparent() -> Self
pub const fn transparent() -> Self
Returns fully transparent black.