pub struct EncodedImage(/* private fields */);Implementations
Sourceimpl EncodedImage
impl EncodedImage
Sourcepub fn new(bytes: impl Into<Arc<[u8]>>) -> Self
pub fn new(bytes: impl Into<Arc<[u8]>>) -> Self
Owns encoded bitmap data that may be shared across views.
Panics
Panics if the data exceeds the WinRT buffer limit of 4 GiB.
Sourcepub fn from_static(bytes: &'static [u8]) -> Self
pub fn from_static(bytes: &'static [u8]) -> Self
Retains encoded bitmap data with static storage without copying it.
Panics
Panics if the data exceeds the WinRT buffer limit of 4 GiB.