pub struct Menu { /* private fields */ }Expand description
A context menu whose click callback receives the selected item’s label.
Implementations
Sourceimpl Menu
impl Menu
Sourcepub fn new(
items: impl IntoIterator<Item = MenuItem>,
on_click: impl IntoPayloadCallback<String>,
) -> Self
pub fn new( items: impl IntoIterator<Item = MenuItem>, on_click: impl IntoPayloadCallback<String>, ) -> Self
Creates a menu and a callback that receives the selected item’s label.