pub struct Thickness(/* private fields */);Expand description
Four edge values measured in device-independent pixels (DIPs).
Implementations
Sourceimpl Thickness
impl Thickness
Sourcepub fn xy(horizontal: f64, vertical: f64) -> Self
pub fn xy(horizontal: f64, vertical: f64) -> Self
Uses one DIP value for horizontal edges and another for vertical edges.
Sourcepub fn new(left: f64, top: f64, right: f64, bottom: f64) -> Self
pub fn new(left: f64, top: f64, right: f64, bottom: f64) -> Self
Creates edge values in left, top, right, bottom order, measured in DIPs.
pub fn left(&self) -> f64
pub fn top(&self) -> f64
pub fn right(&self) -> f64
pub fn bottom(&self) -> f64