View

Struct View 

pub struct View(/* private fields */);
A declarative Reactor subtree.

Positional fragments preserve identity by position. Keyed fragments preserve child identity by Key as items are inserted, removed, or reordered.

Implementations

Source

impl View

pub fn empty() -> Self

Creates a fragment with no children.

pub fn component<C: Component>(input: C::Input) -> Self

Creates a component view from its input.

pub fn fragment(children: impl IntoViews) -> Self

Creates a statically shaped fragment whose children are identified by position.

pub fn keyed_fragment<T>(children: impl IntoIterator<Item = T>) -> Self
where T: Into<KeyedView>,

Creates a dynamic fragment whose children are reconciled by key.

pub fn provide<T>( context: &Context<T>, value: T, child: impl Into<Self>, ) -> Self
where T: Clone + PartialEq + 'static,

Provides a context value to child and its descendants.