WindowRef

Struct WindowRef 

pub struct WindowRef { /* private fields */ }
A token-bound capability for a component’s owning window.

Requests are accepted only during create, changed, or update on the owning window. The Pump commits an accepted request after the resulting candidate publishes.

Implementations

Source

impl WindowRef

pub fn request_close(&self) -> bool

Requests that the owning window close after the current component turn publishes.