GridChildExt

Trait GridChildExt 

pub trait GridChildExt: LayoutControl + Sized {
    // Provided methods
    fn grid_row(self, row: i32) -> Self { ... }
    fn grid_column(self, column: i32) -> Self { ... }
    fn grid_row_span(self, span: i32) -> Self { ... }
    fn grid_column_span(self, span: i32) -> Self { ... }
}
Places a concrete native control in its parent Grid.

Components and fragments can produce more than one native root, so place a native wrapper when a composed view needs Grid placement.

use windows_reactor::*;

struct Child;
let _ = View::component::<Child>(()).grid_row(0);
use windows_reactor::*;

let _ = View::fragment((TextBlock::new(), TextBlock::new())).grid_column(0);

Provided Methods

fn grid_row(self, row: i32) -> Self

fn grid_column(self, column: i32) -> Self

fn grid_row_span(self, span: i32) -> Self

fn grid_column_span(self, span: i32) -> Self

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors