ReferenceControl

Trait ReferenceControl 

pub trait ReferenceControl: Sealed + 'static { }
A native control that can be bound to an ElementRef.

This trait is sealed and implemented only for controls whose generated schema supports native references.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors