pub struct View(/* private fields */);Expand description
A declarative Reactor subtree.
Positional fragments preserve identity by position. Keyed fragments preserve child identity by
Key as items are inserted, removed, or reordered.
Implementations
Sourceimpl View
impl View
Sourcepub fn component<C: Component>(input: C::Input) -> Self
pub fn component<C: Component>(input: C::Input) -> Self
Creates a component view from its input.
Sourcepub fn fragment(children: impl IntoViews) -> Self
pub fn fragment(children: impl IntoViews) -> Self
Creates a statically shaped fragment whose children are identified by position.
Sourcepub fn keyed_fragment<T>(children: impl IntoIterator<Item = T>) -> Self
pub fn keyed_fragment<T>(children: impl IntoIterator<Item = T>) -> Self
Creates a dynamic fragment whose children are reconciled by key.