pub struct WindowRef { /* private fields */ }Expand description
A token-bound capability for a component’s owning window.
Requests are accepted only during create, changed, or update on the owning window. The
Pump commits an accepted request after the resulting candidate publishes.
Implementations